baikalctl
=========


![Image](https://img.shields.io/github/license/rstms/baikalctl)

![Image](https://img.shields.io/pypi/v/baikalctl.svg)





Baikal caldav/carddav server admin cli


* Free software: MIT license
* Documentation: https://baikalctl.readthedocs.io.



Credits
-------

This package was created with Cookiecutter and `rstms/cookiecutter-python-cli`, a fork of the `audreyr/cookiecutter-pypackage` project template.

[audreyr/cookiecutter](https://github.com/audreyr/cookiecutter)
[audreyr/cookiecutter-pypackage](https://github.com/audreyr/cookiecutter-pypackage)
[rstms/cookiecutter-python-cli](https://github.com/rstms/cookiecutter-python-cli)
